/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * Dambach-Werke GmbH
 * Elektronische Leitsysteme
 * Fritz-Minhardt-Str. 1
 * 76456 Kuppenheim
 * Phone: +49-7222-402-0
 * Fax: +49-7222-402-200
 * mailto: info@els.dambach.de
 */
package de.bsvrz.vew.bmvew.bmvew.meldung;


/**
 * Die Klasse arbeitet als Stack mit begrenztem Fassungsvermögen.
 * Wenn die maximale Anzahl erreicht ist, wird das älteste Element
 * ueberschrieben.
 *
 * @version $Revision: 1.3 $ / $Date: 2015/06/09 13:02:12 $ / ($Author: Pittner $)
 *
 * @author Dambach-Werke GmbH
 * @author Timo Pittner
 *
 */
public class InformationsAnteilListe
{
  /**
   * Die Groesse der Infoanteil-Liste
   */
  private int MAX_SIZE = 10;

  /**
   * Die Tiefe
   */
  private int tiefe = 0;
  
  /**
   * Das Feld der Infoanteile
   */
  private InformationsAnteil[] stack;

  /**
   *  Konstruktor
   */
  public InformationsAnteilListe()
  {
        
    stack = new InformationsAnteil[MAX_SIZE];

  }

  /**
   * Konstruktor
   * 
   * @param size Size
   *          
   */
  public InformationsAnteilListe(int size)
  {

    MAX_SIZE = size;
    stack = new InformationsAnteil[MAX_SIZE];

  }

  /**
   * Legt ein Objekt auf den Stack
   * 
   * @param n Element
   */
  public void push(InformationsAnteil n)
  {
    // Stack ist voll
    if (tiefe >= MAX_SIZE)
    {

      for (int i = 0; i < stack.length; i++)
      {
        // Umsortieren, damit das oberste Element frei wird.
        // Dabei fliegt das unterste Element raus!
        if (i < stack.length - 1)
        {
          stack[i] = stack[i + 1];

        }
        else // n wird oberstes Element 
        {
          stack[i] = n;
        }

      }
    }
    else
      stack[tiefe++] = n;
  }

  /**
   * Holt ein Objekt vom Stack
   * 
   * @return Element
   */
  public InformationsAnteil pop()
  {
    return stack[--tiefe];
  }

  /**
   * Liest das oberste Element des Stacks
   * 
   * @return Element
   */
  public InformationsAnteil peek()
  {

    return stack[tiefe - 1];
  }

  /**
   * Liest alle Elemente des Stack
   * 
   * @return Feld der Elemente
   */
  public InformationsAnteil[] getAll()
  {

    InformationsAnteil[] tmp = new InformationsAnteil[tiefe];

    int cnt = 0;
    for (int i = tiefe - 1; i >= 0; i--)
    {
      tmp[cnt++] = stack[i];
    }

    return tmp;
  }
  
  

  /**
   * Ermittelt die Anzahl der Elemente
   * 
   * @return Anzahl
   */
  public int size()
  {
    return tiefe;
  }
}
