/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * Dambach-Werke GmbH
 * Elektronische Leitsysteme
 * Fritz-Minhardt-Str. 1
 * 76456 Kuppenheim
 * Phone: +49-7222-402-0
 * Fax: +49-7222-402-200
 * mailto: info@els.dambach.de
 */

package de.bsvrz.vew.bmvew.bmvew.regel;

import de.bsvrz.dav.daf.main.Data;
import de.bsvrz.dav.daf.main.ResultData;

/**
 * Die Klasse kapselt einen Filter und die ensprechenden Aktion
 * 
 * @version $Revision: 1.1 $ / $Date: 2009/09/24 12:50:46 $ / ($Author: Pittner $)
 * @author Dambach-Werke GmbH
 * @author Timo Pittner
 */
public class Regel
{
  /**
   * Die Aktion
   */
  private Aktion[] aktionen = null;

  /**
   * Der Filter
   */
  private Filter[] filters = null;

  /**
   * Die Betriebsmeldung
   */
  private Data betriebsMeldung = null;

  /**
   * Initialisiert die Regel
   * 
   * @param filters Filters
   * 
   * @param aktionen Aktionen
   * 
   * @throws IllegalArgumentException Exception
   */
  public void initialisiere(Filter[] filters, Aktion[] aktionen) throws IllegalArgumentException
  {

    if (filters == null || aktionen == null)
    {

      throw new IllegalArgumentException();
    }
    
    this.filters = filters;
    this.aktionen = aktionen;

  }

  /**
   * Arbeitet die Regel ab
   * 
   * @param betriebsMeldung Betriebsmeldung
   * 
   * @return false, wenn Aktion Abbruch 
   *        
   */
  public boolean bearbeite(ResultData betriebsMeldung)
  {
    
    Boolean[] flags = new Boolean[filters.length];

    for (int i = 0; i < filters.length; i++)
    {       
        flags[i] = false;
    }

    for (int i = 0; i < filters.length; i++)
    {       
      if (filters[i].pruefe(betriebsMeldung.getData()))
      {
        flags[i] = true;
      }      
    }
    
    Boolean ausfuehren = true;
    
    for (int i = 0; i < filters.length; i++)
    {       
        if (flags[i] == false)
          ausfuehren = false;
    }

    if (ausfuehren){
      
      for (int j = 0; j < aktionen.length; j++)
      {
      
        // Aktion wird ausgeführt
        if (aktionen[j].ausfuehren(betriebsMeldung))
        {
          // Aktion ausgeführt, kein Abbruch
        }
        else
        {
          // Aktion ausgeführt, Abbruch!!!
          return false;

        }
        
      }
      return true;
      
    }else    
      return true;

  }

  public Aktion[] getAktionen()
  {
    return aktionen;
  }

  public void setAktionen(Aktion[] aktionen)
  {
    this.aktionen = aktionen;
  }

  public Filter[] getFilters()
  {
    return filters;
  }

  public void setFilters(Filter[] filters)
  {
    this.filters = filters;
  }

}
