/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * Dambach-Werke GmbH
 * Elektronische Leitsysteme
 * Fritz-Minhardt-Str. 1
 * 76456 Kuppenheim
 * Phone: +49-7222-402-0
 * Fax: +49-7222-402-200
 * mailto: info@els.dambach.de
 */

package de.bsvrz.vew.bmvew.bmvew.sender;

import java.util.Date;
import java.util.Timer;

import de.bsvrz.dav.daf.main.ClientDavInterface;
import de.bsvrz.dav.daf.main.DataDescription;
import de.bsvrz.dav.daf.main.config.Aspect;
import de.bsvrz.dav.daf.main.config.AttributeGroup;
import de.bsvrz.sys.funclib.debug.Debug;
import de.bsvrz.vew.bmvew.bmvew.BetriebsMeldungApp;
import de.bsvrz.vew.bmvew.bmvew.meldung.Meldung;


/**
 * Klasse stellt einen Wecker dar, wenn abgelaufen, die Run-Methode einer Von TimerTask 
 * ableiteten Klasse aufruft
 * 
 * @version $Revision: 1.1 $ / $Date: 2009/09/24 12:50:46 $ / ($Author: Pittner $)
 * @author Dambach-Werke GmbH
 * @author Timo Pittner
 */
public class ErinnerungsFunktion
{
  
  /**
   * Das Meldungs Objekt
   */
  private Meldung meldung;
  

  /**
   * Das Meldungs Objekt
   */
  private Long zeit;

  /**
   * Das Timer Objekt
   */
  private Timer timer = new Timer();


  /**
   * Der Debugger, stellt verschiedene Protokollierungsfunktionen zur Verfügung
   */
  private Debug _debug;

  /**
   * Konstruktor der Klasse
   * 
   * @param meldung Meldung
   *
   * @param zeit Zeit
   *
   */
  public ErinnerungsFunktion(Meldung meldung, Long zeit)
  {
    this.meldung = meldung;
    this.zeit = zeit;

    _debug = Debug.getLogger();
     
    load(zeit);

    
  }

  /**
   * stellt den Timer 
   * 
   * @param l Zeit
   */
  public void load(Long l)
  {
    Date date = new Date();
    date.setTime(zeit);

    ClientDavInterface con = BetriebsMeldungApp.getConnection();
    AttributeGroup atg = con.getDataModel().getAttributeGroup("atg.meldung");
    Aspect asp = con.getDataModel().getAspect("asp.zustand");
    DataDescription dd = new DataDescription(atg, asp);
    
    timer.schedule(new SenderZeitGesteuert(con, meldung, dd), date);

  }

  /**
   * loescht den Timer
   */
  public void unload()
  {

    timer.cancel();

  }
}